
package ice.browser;

import ice.storm.*;
import java.awt.*;
import java.io.File;
import java.net.URL;

import java.util.Vector;

/**
* This is the Main class for sample browser application. It uses
* ICE Browser 5 component to display content. Note that this
* browser application does not install SecurityManager,
* jar protocol handler, cookies and authentication support. 
* For examples on how to do that, please, take a look at 
* ice.browser.MainPro.
*/
public class Main {

    final static String helpMsg = "\n" + 
    "    ICEBrowser 5.x supports several options which might be useful.\n\n"+
    "    This list summarises a few of those options:\n" +
    "\n" +
    "--help    prints this help\n" +
    "-p        prints the DOM tree to ice_output.txt in current directory\n" +
    "-t:XXX    names toolkit to use.  Default is awt, another option is swing\n" +
    "-nosm     specifies that there should be no security manager\n" +
    "-hNUM     specifies height of window\n" +
    "-wNUM     specifies width of window\n" +
    "-c:XXX    names compatibility mode.  Default is icebrowser. Other options are\n" + 
    "          'ns' for Netscape 4, and 'ie' for Internet Exploder 5, and even 'ns+'\n" + 
    "          for the braver fellows.";
    
    final static public void main(String args[]) {

	// Compatibility mode
	String cmode="ib";

	// Try to get the toolkit name
	String tname = "awt";

	// Install security manager?
	boolean securityManager=true;

	for(int i=0;i<args.length;i++) {
	    if (args[i].startsWith("-t:")) {
		tname = args[i].substring(3);
	    }
	    else if (args[i].startsWith("-c:")) {
		cmode = args[i].substring(3);
	    }
	    else if (args[i].equals("-nosm")) {
		securityManager=false;
	    }
	    else if (args[i].equals("--help")) {
		System.out.println(helpMsg);
		return;
	    }
			
	}


	// By default we install our own URLStreamHandlerFactory
	// but make sure that our http and https is turned off.
	ice.net.URLStreamHandlerFactory f = new ice.net.URLStreamHandlerFactory();
	f.removeStreamHandler("http");
	f.removeStreamHandler("https");
	URL.setURLStreamHandlerFactory(f);

	// Now comes the tricky part - jar: protocol.
	// If IB5 runs under Java2, we rely on Java2's built-in 
	// jar protocol. However under JDK 1.1 we need to install
	// IB5's jar protocol handler.
	// NOTE: You must not install it under Java2!!!

	try {

	    // Maybe there is a better way to check whether we are
	    // running under Java 1.1 or Java2.
	    String s = System.getProperty("java.version");
	    if (s==null||(s.indexOf("1.2")<0&&s.indexOf("1.3")<0)) {

	// Check if jar protocol already exists in the system.
		try {
			URL u = new URL("jar://test");
		}
		catch(Exception ex) {
			f.addStreamHandler("jar","ice.storm.JarHandler_jdk11");
		}

		if (securityManager) {
		    System.setSecurityManager(new ice.storm.SecurityManager_jdk11());
		}
	    }
	    else {
	    }
	}
	catch(Exception ex) {}
	{
	    String appName=null;
	    String appVersion=null;

	    if (cmode!=null) {
		if (cmode.equals("ns")) {
		    appName = "Netscape";
		    appVersion = "4.7 [en] (Win98; I)";
		    cmode = "Mozilla/"+appVersion;
		}
		else if (cmode.equals("ns+")) {
		    appName = "Netscape";
		    appVersion = "4.7 [en] ( X11 ; U; " + System.getProperty("os.name") + " " +
			System.getProperty("os.version") + " " + System.getProperty("os.arch")  +" )";
		    cmode = "Mozilla/"+appVersion;
		}
		else if (cmode.equals("ns6")) {
		    appName = "Netscape";
		    appVersion = "5.0 (Windows; en-US)";
		    cmode = "Mozilla/5.0 (Windows; N; Win98; en-US; m14) Netscape6/6.0b1";
		}
		else if (cmode.equals("ie")) {
		    appName = "Microsoft Internet Explorer";
		    appVersion = "4.0 (compatible; MSIE 5.0; Windows 98)";
		    cmode = "Mozilla/"+appVersion;
		}
		else {
		    cmode=null;
		}
	    }

	    if (cmode != null) {
		java.util.Properties prop = System.getProperties();
		prop.put("ice.browser.http.agent",cmode);
		prop.put("ice.browser.appName",appName);
		prop.put("ice.browser.appVersion",appVersion);
	    }
	}


	// Storage of running modules
	Vector modules = new Vector();

	// Init any special modules
	for(int i=0;i<args.length;i++) {
	    if (args[i].startsWith("-m:")) {
		String mname = args[i].substring(3);
		try {
		    Class c = Class.forName("ice.browser."+mname);
		    Runnable r = (Runnable)c.newInstance();
		    r.run();
		    modules.addElement(r);
		}
		catch(Exception ex) {
		    System.out.println("Could not load module \""+mname+"\"");
		}
	    }
	}


	// Create the StormBase object
	StormBase base = new StormBase();
	
	// user specified file name for parse tree
	String parseFile=System.getProperty("ice.browser.parseTreeOutput");
	
	// listen for visited links
	base.addPropertyChangeListener(new VisitedLinks(),null);

	base.setComponentToolkitName(tname);

	// Init the browser for toolkit "tname"
	try {
	    Class c = Class.forName("ice.browser.MyCallback_"+tname);
	    StormCallback cb = (StormCallback)c.newInstance();
	    base.setCallback(cb);
	}
	catch(Exception ex) {
		System.out.println("Could not run browser for toolkit \""+tname+"\"");
		return;
	}


	// A lot of code to parse command-line parameters
	int counter=0;
	for (int i=0; i < args.length; i++) {
	    if (args[i].startsWith("-p")||parseFile!=null) {
		try {
		    base.addPropertyChangeListener(new ParseTreePrinter(parseFile),null);  
		}
		catch(Exception ex) {}
	    }
	    if (args[i].startsWith("-w")) {
		try {
		    reqWidth=Integer.parseInt(args[i].substring(2));
		}
		catch(Exception ex) {}
	    }
	    else if (args[i].startsWith("-h")) {
		try {
		    reqHeight=Integer.parseInt(args[i].substring(2));
		}
		catch(Exception ex) {}
	    }
	    else if (!args[i].startsWith("-")) {
		String loc=args[i];
		// Is this a filename or a real url?
		if (loc.indexOf(":")<0) {
			File file = new File(loc);
			if (file.exists()) {
				try {
					String path = file.getAbsolutePath();
					if (File.separatorChar == '\\') {
						loc="file://localhost/"+path.replace('\\','/');
					}
					else {
						loc="file://localhost"+path;
					}
				}
				catch(RuntimeException ex) {}
			}
			else {
				loc = "http://" + loc;
			}
		}
		base.renderContent(loc,null,"icemain" + counter);
		counter++;
	    }
	}

	if (counter==0) {
	    base.renderContent("http://www.icesoft.no",null,"icemain0");
	}
    }


    static int reqWidth=600, reqHeight=600;
}



